@@ -3,13 +3,15 @@
 // Set new include path:
 ini_set( "include_path" ,ini_get( 'include_path' ) . PATH_SEPARATOR . '/usr/share/mediawiki-extensions/include' );
 
+$dir = "/etc/mediawiki-extensions/extensions-enabled";
+
 // Including all enabled extensions.
-if ( is_dir( "/etc/mediawiki-extensions/extensions-enabled" )
+if ( is_dir( $dir )
    &&
-     $dh = opendir( "/etc/mediawiki-extensions/extensions-enabled" ) ) {
+     $dh = opendir( $dir ) ) {
         while ( ( $file = readdir( $dh ) ) !== false ) {
-	    if ( preg_match( "/.php$/",$file ) ) {
-                include_once( "/etc/mediawiki-extensions/extensions-enabled/" . $file );
+	    if ( preg_match( "/.php$/",$file ) && is_readable($dir . DIRECTORY_SEPARATOR . $file) ) {
+                include_once( $dir . DIRECTORY_SEPARATOR . $file );
             }
         }
         closedir( $dh );
